<?php
class CollectionDetailAction extends BaseAction {
	public function action(ActionInfo &$actionInfo) {
		$form = &$actionInfo->form;
		$request = &$actionInfo->request;
		
		// 入力値チェック
		$validate = TRUE;
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'seq', 'Seq', $request["seq"], TRUE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList, "pageNo", "PageNo", $request["pageNo"], FALSE, TRUE);
		if (!$validate) {
			// エラー
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		// 入力値を取得
		$seq = $actionInfo->request['seq'];
		$pageNo = (!isBlank($request["pageNo"])) ? (int)$request["pageNo"] : 1;
		
		// 処理
		$themeDtoDao = new ThemeDtoDao();
		$collectionDtoDao = new CollectionDtoDao();
		$collectionDto = $collectionDtoDao->find($seq,TRUE);
		if ($collectionDto == NULL) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_COLLECTION_INFO_NOT_FOUND, array($seq));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		$themeDto = $themeDtoDao->find($collectionDto->themeSeq, FALSE);
		if ($themeDto == NULL) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_THEME_INFO_NOT_FOUND, array($collectionDto->themeSeq));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// アクセス権限チェック
		if (!AuthorityUtil::isCollectionBrowsable($themeDto, $collectionDto)) {
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_AUTHORITY);
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// currentCollectionDetailDtoを設定する
		if (!isset($collectionDto->collectionDetailDtoList[$pageNo-1])) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_COLLECTION_DETAIL_INFO_NOT_FOUND, array($seq,$pageNo));
			$actionInfo->forwardActionName = "ThemeList";
			return;
		}
		$collectionDetailDto = $collectionDto->collectionDetailDtoList[$pageNo-1];
		
		// 表示項目に値を設定する。
		$themeDtoArray = array();
		$collectionDtoArray = array();
		$collectionDetailDtoArray = array();
		$themeDto->copyToArray($themeDtoArray);
		$collectionDto->copyToArray($collectionDtoArray);
		$collectionDetailDto->copyToArray($collectionDetailDtoArray);
		
		$totalPageNo = count($collectionDto->collectionDetailDtoList);
		$actionInfo->form['pageNo'] = ($pageNo < $totalPageNo) ? $pageNo : $totalPageNo;;
		$actionInfo->form['totalPageNo'] = $totalPageNo;
		$actionInfo->form['prevPageNo'] = ($pageNo > 1) ? ($pageNo - 1) : NULL;
		$actionInfo->form['nextPageNo'] = ($pageNo < $totalPageNo) ? ($pageNo + 1) : NULL;
		$actionInfo->form['prevSeq'] = $collectionDto->seq;
		$actionInfo->form['nextSeq'] = $collectionDto->seq;
		$actionInfo->form['themeDto'] = $themeDtoArray;
		$actionInfo->form['collectionDto'] = $collectionDtoArray;
		$actionInfo->form['collectionDetailDto'] = $collectionDetailDtoArray;
		
		if (isBlank($actionInfo->form['prevPageNo'])) {
			$tempCollectionDto = $collectionDto;
			while (TRUE) {
				$tempCollectionDto = $collectionDtoDao->findPrevByThemeSeqAndSortNo($tempCollectionDto->themeSeq, $tempCollectionDto->sortNo, TRUE);
				if ($tempCollectionDto != NULL) {
					if (AuthorityUtil::isCollectionBrowsable($themeDto, $tempCollectionDto) && count($tempCollectionDto->collectionDetailDtoList) > 0) {
						$actionInfo->form['prevPageNo'] = count($tempCollectionDto->collectionDetailDtoList);
						$actionInfo->form['prevSeq'] = $tempCollectionDto->seq;
						break;
					} else {
						// 繰り返し
					}
				} else {
					break;
				}
			}
		}
		if (isBlank($actionInfo->form['nextPageNo'])) {
			$tempCollectionDto = $collectionDto;
			while (TRUE) {
				$tempCollectionDto = $collectionDtoDao->findNextByThemeSeqAndSortNo($tempCollectionDto->themeSeq, $tempCollectionDto->sortNo, TRUE);
				if ($tempCollectionDto != NULL) {
					if (AuthorityUtil::isCollectionBrowsable($themeDto, $tempCollectionDto) && count($tempCollectionDto->collectionDetailDtoList) > 0) {
						$actionInfo->form['nextPageNo'] = 1;
						$actionInfo->form['nextSeq'] = $tempCollectionDto->seq;
						break;
					} else {
						// 繰り返し
					}
				} else {
					break;
				}
			}
		}
		
		// commonInfoを設定する
		$actionInfo->form["commonInfo"] = array(
			"themeSeq" => $collectionDto->themeSeq,
			"themeName" => ($themeDto !== NULL) ? $themeDto->title1 : "",
			"collectionSeq" => $collectionDto->seq,
			"collectionName" => $collectionDto->title1,
			"pageNo" => $pageNo,
		);
		$actionInfo->title = $collectionDto->title1;
		$actionInfo->viewName = 'CollectionDetailView';
	}
}
?>