<?php
class CollectionEditAction {
	public function action(ActionInfo &$actionInfo) {
		if (count($actionInfo->commands) == 0) {
			$actionInfo->errorMessageList[] = getMessage(MSG_ACTION_NEEDS_COMMAND, array($actionInfo->actionName));
			$actionInfo->viewName = "CollectionBrowseView";
		} else {
			$command = $actionInfo->commands[0];
			if ($command == "createCollection") {
				$this->createCollection($actionInfo);
			} else if ($command == "editCollection") {
				$this->editCollection($actionInfo);
			} else if ($command == "deleteCollection") {
				$this->deleteCollection($actionInfo);
			} else if ($command == "reloadCollection") {
				$this->reloadCollection($actionInfo);
			} else if ($command == "uploadImage") {
				$this->uploadImage($actionInfo);
			} else if ($command == "deleteImage") {
				$idx = (count($actionInfo->commands) > 1) ? $actionInfo->commands[1] : -1;
				$this->deleteImage($actionInfo, $idx);
			} else if ($command == "moveUp") {
				$idx = (count($actionInfo->commands) > 1) ? $actionInfo->commands[1] : -1;
				$this->moveUp($actionInfo, $idx);
			} else if ($command == "moveDown") {
				$idx = (count($actionInfo->commands) > 1) ? $actionInfo->commands[1] : -1;
				$this->moveDown($actionInfo, $idx);
			} else {
				$actionInfo->errorMessageList[] = getMessage(MSG_UNKNOWN_ACTION_COMMAND, array($actionInfo->actionName, $command));
				$actionInfo->viewName = "CollectionBrowseView";
			}
		}
	}
	public function createCollection(ActionInfo &$actionInfo) {
		$request = $actionInfo->request;
		$collectionDtoArray = (isset($actionInfo->request["collectionDto"])) ? $actionInfo->request["collectionDto"] : array();
		
		// 入力値チェック
		$validate = TRUE;
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'themeSeq', 'ThemeSeq', $collectionDtoArray["themeSeq"], TRUE, TRUE);
		if (!$validate) {
			// エラー
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		$themeSeq = $collectionDtoArray["themeSeq"];
		
		// T_THEMEテーブルより、ThemeDtoを取得する。
		$themeDtoDao = new ThemeDtoDao();
		$themeDto = $themeDtoDao->find($themeSeq, TRUE);
		if ($themeDto == NULL) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_THEME_INFO_NOT_FOUND, array($seq));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// 権限チェック
		if (!AuthorityUtil::isCollectionCreatable($themeDto)) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_AUTHORITY);
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// 現在のユーザの、このテーマのコレクション数を取得する。
		$userDto = UserUtil::getUserInfo();
		$collectionDtoDao = new CollectionDtoDao();
		$collectionDtoList = $collectionDtoDao->findByThemeSeqAndUserSeq($themeSeq, $userDto->seq, FALSE);
		if ($themeDto->collectionNum >0 && count($collectionDtoList) > $themeDto->collectionNum) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_COLLECTION_NUM_OVER, array($themeDto->collectionNum));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// 表示項目に値を設定する。
		$actionInfo->form["collectionDto"] = $collectionDtoArray; 
		
		$actionInfo->viewName = "CollectionEditView";
	}
	public function editCollection(ActionInfo &$actionInfo) {
		$request = $actionInfo->request;
		
		// 入力値チェック
		$validate = TRUE;
		$collectionDtoArray = (isset($request["collectionDto"])) ? $request["collectionDto"] : array(); 
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'collectionSeq', 'Seq', $collectionDtoArray["seq"], TRUE, TRUE);
		if (!$validate) {
			// エラー
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		$collectionSeq = $collectionDtoArray["seq"];
		
		$collectionDtoDao = new CollectionDtoDao();
		$collectionDto = $collectionDtoDao->find($collectionSeq,TRUE);
		if ($collectionDto == NULL) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_COLLECTION_INFO_NOT_FOUND, array($seq));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		$themeDtoDao = new ThemeDtoDao();
		$themeDto = $themeDtoDao->find($collectionDto->themeSeq,TRUE);
		if ($themeDto == NULL) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_THEME_INFO_NOT_FOUND, array($seq));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// 権限チェック
		if (!AuthorityUtil::isCollectionEditable($themeDto, $collectionDto)) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_AUTHORITY);
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// 表示項目に値を設定する。
		$collectionDtoArray = array();
		$collectionDto->copyToArray($collectionDtoArray);
		$actionInfo->form["collectionDto"] = $collectionDtoArray;
		
		$actionInfo->viewName = "CollectionEditView";
	}
	public function deleteCollection(ActionInfo &$actionInfo) {
		$request = $actionInfo->request;
		
		// 入力値チェック
		$validate = TRUE;
		$collectionDtoArray = (isset($request["collectionDto"])) ? $request["collectionDto"] : array(); 
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'collectionSeq', 'Seq', $collectionDtoArray["seq"], TRUE, TRUE);
		if (!$validate) {
			// エラー
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		$collectionSeq = $collectionDtoArray["seq"];
		
		$collectionDtoDao = new CollectionDtoDao();
		$collectionDto = $collectionDtoDao->find($collectionSeq,TRUE);
		if ($collectionDto == NULL) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_COLLECTION_INFO_NOT_FOUND, array($seq));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		$themeDtoDao = new ThemeDtoDao();
		$themeDto = $themeDtoDao->find($collectionDto->themeSeq,TRUE);
		if ($themeDto == NULL) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_THEME_INFO_NOT_FOUND, array($seq));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// 権限チェック
		if (!AuthorityUtil::isCollectionEditable($themeDto, $collectionDto)) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_AUTHORITY);
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// 表示項目に値を設定する。
		$collectionDtoArray = array();
		$collectionDto->copyToArray($collectionDtoArray);
		$actionInfo->form["collectionDto"] = $collectionDtoArray;
		
		$actionInfo->viewName = "CollectionDeleteView";
	}
	public function reloadCollection(ActionInfo &$actionInfo) {
		$actionInfo->form = $actionInfo->request;
		
		$actionInfo->viewName = 'CollectionEditView';
	}
	public function uploadImage(ActionInfo &$actionInfo) {
		$imageFile = $_FILES["imageFile"];
		
		if (!isset($imageFile) || !is_uploaded_file($imageFile["tmp_name"])) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_FILE_IS_UPLOADED);
			$actionInfo->viewName = "CollectionEditView";
			return;
		}
		$userDto = UserUtil::getUserInfo();
		$imageDto = ImageUtil::createImageDto($userDto, $imageFile, $actionInfo->errorMessageList);
		if ($imageDto == NULL) {
			// エラー
			$actionInfo->viewName = "CollectionEditView";
			return;
		}
		
		$collectionDetailDto = new CollectionDetailDto();
		$collectionDetailDto->imageSeq = $imageDto->seq;
		$collectionDetailDto->imageRealFileName = $imageDto->imageRealFileName;
		$collectionDetailDto->imageOriginalFileName = $imageDto->imageOriginalFileName;
		$collectionDetailDto->thumbnailRealFileName = $imageDto->thumbnailRealFileName;
		$collectionDetailDto->thumbnailOriginalFileName = $imageDto->thumbnailOriginalFileName;
		
		
		$actionInfo->form = $actionInfo->request;
		$collectionDetailDtoArray = array();
		$collectionDetailDto->copyToArray($collectionDetailDtoArray);
		$actionInfo->form["collectionDto"]["collectionDetailDtoList"][] = $collectionDetailDtoArray;
		
		$actionInfo->viewName = "CollectionEditView";
	}
	public function deleteImage(ActionInfo &$actionInfo, $idx) {
		$form = &$actionInfo->request;
		$collectionDto = &$form["collectionDto"];
		if (isset($collectionDto)) {
			$collectionDetailDtoList = &$collectionDto["collectionDetailDtoList"];
			if (isset($collectionDetailDtoList)) {
				if (isset($collectionDetailDtoList[$idx])) {
					array_splice($collectionDetailDtoList, $idx, 1);
				}
			}
		}
		
		$actionInfo->form = &$form;
		$actionInfo->viewName = "CollectionEditView";
	}
	public function moveUp(ActionInfo &$actionInfo, $idx) {
		$form = &$actionInfo->request;
		$collectionDto = &$form["collectionDto"];
		if (isset($collectionDto)) {
			$collectionDetailDtoList = &$collectionDto["collectionDetailDtoList"];
			if (isset($collectionDetailDtoList)) {
				if (isset($collectionDetailDtoList[$idx]) && isset($collectionDetailDtoList[$idx-1])) {
					$t = $collectionDetailDtoList[$idx];
					$collectionDetailDtoList[$idx] = $collectionDetailDtoList[$idx-1];
					$collectionDetailDtoList[$idx-1] = $t;
				}
			}
		}
		
		$actionInfo->form = &$form;
		$actionInfo->viewName = "CollectionEditView";
	}
	public function moveDown(ActionInfo &$actionInfo, $idx) {
		$form = &$actionInfo->request;
		$collectionDto = &$form["collectionDto"];
		if (isset($collectionDto)) {
			$collectionDetailDtoList = &$collectionDto["collectionDetailDtoList"];
			if (isset($collectionDetailDtoList)) {
				if (isset($collectionDetailDtoList[$idx]) && isset($collectionDetailDtoList[$idx+1])) {
					$t = $collectionDetailDtoList[$idx];
					$collectionDetailDtoList[$idx] = $collectionDetailDtoList[$idx+1];
					$collectionDetailDtoList[$idx+1] = $t;
				}
			}
		}
		
		$actionInfo->form = &$form;
		$actionInfo->viewName = "CollectionEditView";
	}
}
?>