<?php
class CollectionRegisterAction extends BaseAction {
	public function action(ActionInfo &$actionInfo) {
		$command = (count($actionInfo->commands) > 0) ? $actionInfo->commands[0] : NULL;
		if (isBlank($command)) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_COMMAND);
			$actionInfo->viewName = "AppricationErrorView";
			return;
		} else if ($command == "confirm") {
			$this->confirm($actionInfo);
		} else if ($command == "register") {
			$this->register($actionInfo);
		} else if ($command == "delete") {
			$this->delete($actionInfo);
		} else {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_UNKNOWN_COMMAND, array($command));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
	}
	
	public function confirm(ActionInfo &$actionInfo) {
		// 入力値チェック
		$validate = $this->validate($actionInfo);
		if (!$validate) {
			// エラー
			$actionInfo->form = $actionInfo->request;
			$actionInfo->viewName = "CollectionEditView";
			return;
		}
		
		$actionInfo->form = $actionInfo->request;
		$actionInfo->viewName = "CollectionConfirmView";
	}
	public function register(ActionInfo &$actionInfo) {
		// 入力値チェック
		$validate = $this->validate($actionInfo);
		
		if (!$validate) {
			// エラー
			$actionInfo->form = $actionInfo->request;
			$actionInfo->viewName = "collectionConfirmView";
			return;
		}
		$collectionDtoArray = $actionInfo->request["collectionDto"];
		$themeSeq = $collectionDtoArray["themeSeq"];
		
		// formからdtoに変換
		$userDto = UserUtil::getUserInfo();
		$collectionDto = new CollectionDto();
		$collectionDto->copyFromArray($collectionDtoArray);
		if (isBlank($collectionDto->userSeq)) {
			$collectionDto->userSeq = $userDto->seq;
		}
		$sortNo = 0;
		foreach($collectionDto->collectionDetailDtoList as $collectionDetailDto) {
			$collectionDetailDto->sortNo = $sortNo;
			$sortNo++;
		}

		// T_THEMEテーブルより、ThemeDtoを取得する。
		$themeDtoDao = new ThemeDtoDao();
		$themeDto = $themeDtoDao->find($themeSeq, TRUE);
		if ($themeDto == NULL) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_THEME_INFO_NOT_FOUND, array($seq));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// 権限チェック
		if ((isBlank($collectionDto->seq) && !AuthorityUtil::isCollectionCreatable($themeDto))
			|| (!isBlank($collectionDto->seq) && !AuthorityUtil::isCollectionEditable($themeDto,$collectionDto)))
		{
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_AUTHORITY);
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// 古い値の保持
		$this->retainCollectionDtoValues($collectionDto);
		
		// 入力されたテーマ情報をテーブルに登録/更新する。
		$collectionDtoDao = new CollectionDtoDao();
		$collectionDtoDao->register($collectionDto, TRUE);
		
		// 画面を表示する
		$actionInfo->form["seq"] = $collectionDto->seq;
		$actionInfo->noticeMessageList[] = getMessage(MSG_REGISTERING_COLLECTION_SUCCEED);
		$actionInfo->forwardActionName = 'CollectionBrowse';
	}
	public function delete(ActionInfo &$actionInfo) {
		$request = $actionInfo->request;
		
		// 入力値チェック
		$validate = TRUE;
		$collectionDtoArray = (isset($request["collectionDto"])) ? $request["collectionDto"] : array(); 
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'collectionSeq', 'Seq', $collectionDtoArray["seq"], TRUE, TRUE);
		if (!$validate) {
			// エラー
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		$collectionSeq = $collectionDtoArray["seq"];
		
		$collectionDtoDao = new CollectionDtoDao();
		$collectionDto = $collectionDtoDao->find($collectionSeq,TRUE);
		if ($collectionDto == NULL) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_COLLECTION_INFO_NOT_FOUND, array($seq));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		$themeDtoDao = new ThemeDtoDao();
		$themeDto = $themeDtoDao->find($collectionDto->themeSeq,TRUE);
		if ($themeDto == NULL) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_THEME_INFO_NOT_FOUND, array($seq));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// 権限チェック
		if (!AuthorityUtil::isCollectionEditable($themeDto, $collectionDto)) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_AUTHORITY);
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// コレクションの削除を行う
		$collectionDtoDao->delete($collectionSeq);
		
		// テーマ閲覧画面にフォワードする
		$actionInfo->form["seq"] = $themeDto->seq;
		$actionInfo->noticeMessageList[] = getMessage(MSG_DELETING_COLLECTION_SUCCEED);
		$actionInfo->forwardActionName = "ThemeBrowse";
	}
	
	private function validate(ActionInfo &$actionInfo) {
		$collectionDtoArray = (isset($actionInfo->request["collectionDto"])) ? $actionInfo->request["collectionDto"] : array(); 

		$validate = TRUE;
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'seq', 'Seq', $collectionDtoArray["seq"], FALSE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'themeSeq', 'ThemeSeq', $collectionDtoArray["themeSeq"], TRUE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'subSeq', 'SubSeq', $collectionDtoArray["subSeq"], FALSE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'title1', 'Title1', $collectionDtoArray["title1"], TRUE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'title2', 'Title2', $collectionDtoArray["title2"], FALSE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'title3', 'Title3', $collectionDtoArray["title3"], FALSE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'title4', 'Title4', $collectionDtoArray["title4"], FALSE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'description1', 'Description1', $collectionDtoArray["description1"], TRUE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'description2', 'Description2', $collectionDtoArray["description2"], FALSE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'description3', 'Description3', $collectionDtoArray["description3"], FALSE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'description4', 'Description4', $collectionDtoArray["description4"], FALSE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'sortNo', 'SortNo', $collectionDtoArray["sortNo"], TRUE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'collectionStatus', 'CollectionStatus', $collectionDtoArray["collectionStatus"], TRUE, TRUE);
		$themeSeq = $collectionDtoArray["themeSeq"];

		$collectionDetailDtoListArray = $collectionDtoArray["collectionDetailDtoList"];
		if (isset($collectionDetailDtoListArray) && is_array($collectionDetailDtoListArray)) {
			$lines = array($key);
			foreach($collectionDetailDtoListArray as $key => $collectionDetailDtoArray) {
				$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'userSeq', 'Seq', $collectionDetailDtoArray["imageSeq"], TRUE, TRUE, $lines);
			}
			
			// T_THEMEテーブルより、ThemeDtoを取得する。
			$themeDtoDao = new ThemeDtoDao();
			$themeDto = $themeDtoDao->find($themeSeq, TRUE);
			if ($themeDto == NULL) {
				// エラー
				$actionInfo->errorMessageList[] = getMessage(MSG_THEME_INFO_NOT_FOUND, array($seq));
				$actionInfo->viewName = "AppricationErrorView";
				return;
			}
			
			// このテーマのコレクション詳細の個数のチェック
			if ($themeDto->collectionDetailNum >0 && count($collectionDetailDtoListArray) > $themeDto->collectionDetailNum) {
				// エラー
				$actionInfo->errorMessageList[] = getMessage(MSG_COLLECTION_DETAIL_NUM_OVER, array($themeDto->collectionDetailNum));
				$actionInfo->viewName = "AppricationErrorView";
				return;
			}
		}
		return $validate;
	}

	private function retainCollectionDtoValues(CollectionDto &$dto) {
		if (!isBlank($dto->seq)) {
			$collectionDtoDao = new CollectionDtoDao();
			$oldDto = $collectionDtoDao->find($dto->seq, FALSE);
			if ($oldDto != null) {
				$dto->title1 = (isset($dto->title1)) ? $dto->title1 : $oldDto->title1;
				$dto->title2 = (isset($dto->title2)) ? $dto->title2 : $oldDto->title2;
				$dto->title3 = (isset($dto->title3)) ? $dto->title3 : $oldDto->title3;
				$dto->title4 = (isset($dto->title4)) ? $dto->title4 : $oldDto->title4;
				$dto->description1 = (isset($dto->description1)) ? $dto->description1 : $oldDto->description1;
				$dto->description2 = (isset($dto->description2)) ? $dto->description2 : $oldDto->description2;
				$dto->description3 = (isset($dto->description3)) ? $dto->description3 : $oldDto->description3;
				$dto->description4 = (isset($dto->description4)) ? $dto->description4 : $oldDto->description4;
			}
		}
	}
}
?>