<?php
class ManageUserEditAction extends BaseAction {
	public function action(ActionInfo &$actionInfo) {
		$command = (count($actionInfo->commands) > 0) ? $actionInfo->commands[0] : NULL;
		if (isBlank($command)) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_COMMAND);
			$actionInfo->viewName = "AppricationErrorView";
			return;
		} else if ($command == "createUser") {
			$this->createUser($actionInfo);
		} else if ($command == "editUser") {
			$this->editUser($actionInfo);
		} else {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_UNKNOWN_COMMAND, array($command));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
	}
	public function createUser(ActionInfo &$actionInfo) {
		// 入力値チェック
		// なし
		
		// 権限チェック
		if (!UserUtil::isSystemManager()) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_USER_INFO_NOT_EDITABLE,array($seq));
			$actionInfo->viewName= "AppricationErrorView";
			return;
		}
		
		$actionInfo->viewName = 'ManageUserEditView';
	}
	public function editUser(ActionInfo &$actionInfo) {
		$form = &$actionInfo->form;
		$request = &$actionInfo->request;
		$userDtoArray = (isset($request[userDto])) ? $request[userDto] : array(); 
		
		// 入力値チェック
		$validate = TRUE;
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'seq', 'Seq', $userDtoArray["seq"], TRUE, TRUE);
		if (!$validate) {
			// エラー
			$actionInfo->viewName= "AppricationErrorView";
			return;
		}
		$seq = $userDtoArray["seq"];

		// 権限チェック
		if (!UserUtil::isSystemManager()) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_USER_INFO_NOT_EDITABLE,array($seq));
			$actionInfo->viewName= "AppricationErrorView";
			return;
		}
		
		// 処理
		if (isBlank($seq)) {
			$userDto = new UserDto();
		} else {
			$userDtoDao = new UserDtoDao();
			$userDto = $userDtoDao->find($seq,TRUE);
			if ($userDto == NULL) {
				// エラー
				$actionInfo->errorMessageList[] = getMessage(MSG_USER_INFO_NOT_FOUND,array($seq));
				$actionInfo->viewName= "AppricationErrorView";
				return;
			}
		}
		
		// 表示項目に値を設定する。
		$userDtoArray = array();
		$userDto->copyToArray($userDtoArray);
		$actionInfo->form["userDto"] = $userDtoArray;
		$actionInfo->form["userDto"]["themeManager"] = FLAG_FALSE;
		$actionInfo->form["userDto"]["systemManager"] = FLAG_FALSE;
		foreach($userDto->userAttributeDtoList as $userAttributeDto) {
			if ($userAttributeDto->attributeName == AUTHORITY_THEME_MANAGER) {
				$actionInfo->form['userDto']['themeManager'] = $userAttributeDto->attributeValue;
			}
			if ($userAttributeDto->attributeName == AUTHORITY_SYSTEM_MANAGER) {
				$actionInfo->form['userDto']['systemManager'] = $userAttributeDto->attributeValue;
			}
		}
		
		$actionInfo->viewName = 'ManageUserEditView';
	}
}
?>