<?php
class ManageUserListAction extends BaseAction {
	public function action(ActionInfo &$actionInfo) {
		$form = &$actionInfo->form;
		$request = &$actionInfo->request;
		$pageNo = 1;
		
		// Validate
		$validate = TRUE;
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList, "pageNo", "PageNo", $request["pageNo"], FALSE, TRUE);
		if ($validate) {
			if (!isBlank($request["pageNo"])) {
				$pageNo = (int)$request["pageNo"];
			}
		}

		// 権限チェック
		if (!UserUtil::isSystemManager()) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_AUTHORITY);
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// UserDtoのリストを取得する。
		$userDtoDao = new UserDtoDao();
		$listFrom = USER_NUM_PER_PAGE * ($pageNo - 1) + 1;
		$listTo = USER_NUM_PER_PAGE * $pageNo;
		
		// 処理
		$userDtoDao = new UserDtoDao();
		$userDtoList = $userDtoDao->findAll(TRUE, $listFrom, $listTo);
		$userDtoCount = $userDtoDao->findCount();
		$totalPageNo = ceil($userDtoCount / USER_NUM_PER_PAGE);
		
		// 表示項目に値を設定する。
		$actionInfo->form['userDtoList'] = UserDto::createArrayArrayFromDtoArray($userDtoList);
		$actionInfo->form['pageNo'] = ($pageNo < $totalPageNo) ? $pageNo : $totalPageNo;;
		$actionInfo->form['totalPageNo'] = $totalPageNo;
		$actionInfo->form['prevPageNo'] = ($pageNo > 1) ? ($pageNo - 1) : NULL;
		$actionInfo->form['nextPageNo'] = ($pageNo < $totalPageNo) ? ($pageNo + 1) : NULL;
		foreach($userDtoList as $key => $userDto) {
			$actionInfo->form['userDtoList'][$key]['themeManager'] = FLAG_FALSE;
			$actionInfo->form['userDtoList'][$key]['systemManager'] = FLAG_FALSE;
			foreach($userDto->userAttributeDtoList as $userAttributeDto) {
				if ($userAttributeDto->attributeName == AUTHORITY_THEME_MANAGER) {
					$actionInfo->form['userDtoList'][$key]['themeManager'] = $userAttributeDto->attributeValue;
				}
				if ($userAttributeDto->attributeName == AUTHORITY_SYSTEM_MANAGER) {
					$actionInfo->form['userDtoList'][$key]['systemManager'] = $userAttributeDto->attributeValue;
				}
			}
		}
		
		// commonInfoを設定する
		// 無し
		
		$actionInfo->viewName = 'ManageUserListView';
	}
}
?>