<?php
class ManageUserRegisterAction extends BaseAction {
	public function action(ActionInfo &$actionInfo) {
		$form = &$actionInfo->form;
		$request = &$actionInfo->request;
		$command = (count($actionInfo->commands)>0) ? $actionInfo->commands[0] : "";
		
		// ユーザ登録処理
		$userDtoArray = (isset($request['userDto'])) ? $request['userDto'] : array();  
		
		// 入力値チェック
		$validate = TRUE;
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'seq', 'Seq', $userDtoArray["seq"], FALSE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'userId', 'UserId', $userDtoArray["userId"], TRUE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'nickName', 'NickName', $userDtoArray["nickName"], TRUE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'password', 'Password', $userDtoArray["password"], FALSE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'themeManager', 'Flag', $userDtoArray["themeManager"], TRUE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'systemManager', 'Flag', $userDtoArray["systemManager"], TRUE, TRUE);
		if (!$validate) {
			// エラー
			$actionInfo->viewName= "ManageUserEditView";
			$actionInfo->form = $request;
			return;
		}
		$seq = $userDtoArray["seq"]; 
		
		// 権限チェック
		if (!UserUtil::isSystemManager()) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_USER_INFO_NOT_EDITABLE,array($seq));
			$actionInfo->viewName= "AppricationErrorView";
			return;
		}
		
		// 処理
		$userDtoDao = new UserDtoDao();
		if (isBlank($seq)) {
			$userDto = new UserDto();
		} else {
			$userDto = $userDtoDao->find($seq,TRUE);
			if ($userDto == NULL) {
				// エラー
				$actionInfo->errorMessageList[] = getMessage(MSG_USER_INFO_NOT_FOUND,array($seq));
				$actionInfo->viewName= "AppricationErrorView";
				return;
			}
		}
				
		//同一のユーザIDが存在しないか確認する。
		$checkUserDto = $userDtoDao->findByUserId($userDtoArray["userId"]);
		if ($checkUserDto != NULL && $checkUserDto->seq != $userDtoArray["seq"]) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_VALUE_ALREADY_EXISTS, array(getTranslation("userId","DATA_NAME"),$userDtoArray["userId"]));
			$actionInfo->viewName= "UserEditView";
			$actionInfo->form = $request;
			return;
		}
		
		// 取得したユーザ情報に値を設定する。
		$userDto->userId = $userDtoArray['userId'];
		$userDto->nickName = $userDtoArray['nickName'];
		$userDto->enable = $userDtoArray['enable'];
		if (!isBlank($userDtoArray['password'])) {
			$userDto->passwordHash = strtolower(sha1($userDtoArray['password'],FALSE));
		}
		// ユーザ属性情報を作成する。
		$userAttributeDtoList = array();
		if ($userDtoArray["themeManager"]) {
			$userAttributeDto = new UserAttributeDto();
			$userAttributeDto->attributeName = AUTHORITY_THEME_MANAGER;
			$userAttributeDto->attributeValue = FLAG_TRUE;
			$userAttributeDtoList[] = $userAttributeDto;
		}
		if ($userDtoArray["systemManager"]) {
			$userAttributeDto = new UserAttributeDto();
			$userAttributeDto->attributeName = AUTHORITY_SYSTEM_MANAGER;
			$userAttributeDto->attributeValue = FLAG_TRUE;
			$userAttributeDtoList[] = $userAttributeDto;
		}
		$userDto->userAttributeDtoList = $userAttributeDtoList;
		$userDtoDao->register($userDto, TRUE);

		$actionInfo->noticeMessageList[] = getMessage(MSG_REGISTERING_USER_SUCCEED);
		$actionInfo->forwardActionName = 'ManageUserList';
	}
}
?>