<?php
class ThemeBrowseAction extends BaseAction {
	public function action(ActionInfo &$actionInfo) {
		$form = &$actionInfo->form;
		$request = &$actionInfo->request;
		
		// 入力値チェック
		$validate = TRUE;
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'seq', 'Seq', $request["seq"], TRUE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList, "pageNo", "PageNo", $request["pageNo"], FALSE, TRUE);
		if (!$validate) {
			// エラー
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		// 入力値を取得
		$seq = $actionInfo->request['seq'];
		$pageNo = (!isBlank($request["pageNo"])) ? (int)$request["pageNo"] : 1;
		
		// 処理
		$themeDtoDao = new ThemeDtoDao();
		$collectionDtoDao = new CollectionDtoDao();
		$themeDto = $themeDtoDao->find($seq,TRUE);
		if ($themeDto == NULL) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_THEME_INFO_NOT_FOUND, array($seq));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// アクセス権限チェック
		if (!AuthorityUtil::isThemeBrowsable($themeDto)) {
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_AUTHORITY);
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// CollectionDtoの取得
		$listFrom = COLLECTION_NUM_PER_PAGE * ($pageNo - 1) + 1;
		$listTo = COLLECTION_NUM_PER_PAGE * $pageNo;
		$collectionDtoList = $collectionDtoDao->findByThemeSeq($seq, TRUE, NULL, $listFrom, $listTo);
		$collectionDtoCount = $collectionDtoDao->findCountByThemeSeq($seq);
		$totalPageNo = ceil($collectionDtoCount / COLLECTION_NUM_PER_PAGE);
		
		// CollectionDtoのリストの各要素についてアクセス権限の確認を行う
		$collectionBrowsable = array();
		foreach ($collectionDtoList as $cd) {
			$collectionBrowsable[] = AuthorityUtil::isCollectionBrowsable($themeDto, $cd);
		}
		
		// 表示項目に値を設定する。
		$themeDtoArray = array();
		$themeDto->copyToArray($themeDtoArray);
		$actionInfo->form["themeDto"] = $themeDtoArray;
		$actionInfo->form["collectionDtoList"] = CollectionDto::createArrayArrayFromDtoArray($collectionDtoList);
		$actionInfo->form['pageNo'] = ($pageNo < $totalPageNo) ? $pageNo : $totalPageNo;
		$actionInfo->form['totalPageNo'] = $totalPageNo;
		$actionInfo->form['prevPageNo'] = ($pageNo > 1) ? ($pageNo - 1) : NULL;
		$actionInfo->form['nextPageNo'] = ($pageNo < $totalPageNo) ? ($pageNo + 1) : NULL;
		foreach ($collectionBrowsable as $key => $value) {
			$actionInfo->form["collectionDtoList"][$key]["browsableFlag"] = $value;
		}
		$actionInfo->form['themeEditableFlag'] = AuthorityUtil::isThemeEditable($themeDto);
		$actionInfo->form['collectionCreatableFlag'] = AuthorityUtil::isCollectionCreatable($themeDto);
		
		// commonInfoを設定する
		$actionInfo->form["commonInfo"] = array(
			"themeSeq" => $themeDto->seq,
			"themeName" => (!isBlank($themeDto)) ? $themeDto->title1 : "",
		);
		$actionInfo->title = $themeDto->title1;
		$actionInfo->viewName = 'ThemeBrowseView';
	}
}
?>