<?php
class ThemeEditAction extends BaseAction {
	public function action(ActionInfo &$actionInfo) {
		$command = (count($actionInfo->commands) > 0) ? $actionInfo->commands[0] : NULL;
		if (isBlank($command)) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_COMMAND);
			$actionInfo->viewName = "AppricationErrorView";
			return;
		} else if ($command == "createTheme") {
			$this->createTheme($actionInfo);
		} else if ($command == "editTheme") {
			$this->editTheme($actionInfo);
		} else if ($command == "deleteTheme") {
			$this->deleteTheme($actionInfo);
		} else if ($command == "reloadTheme") {
			$this->reloadTheme($actionInfo);
		} else if ($command == "addUser") {
			$this->addUser($actionInfo);
		} else if ($command == "deleteUser") {
			$idx = (count($actionInfo->commands) > 1) ? $actionInfo->commands[1] : -1;
			$this->deleteUser($idx,$actionInfo);
		} else {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_UNKNOWN_COMMAND, array($command));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
	}
	
	public function createTheme(ActionInfo &$actionInfo) {
		// 権限チェック
		if (!AuthorityUtil::isThemeCreatable()) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_AUTHORITY);
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// 表示項目に値を設定する。
		// 初期値無し
		
		$actionInfo->viewName = 'ThemeEditView';
	}
	public function editTheme(ActionInfo &$actionInfo) {
		$form = &$actionInfo->form;
		$request = &$actionInfo->request;
		
		// 入力値チェック
		$validate = TRUE;
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'seq', 'Seq', $request["themeDto"]["seq"], TRUE, TRUE);
		if (!$validate) {
			// エラー
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		$seq = $request["themeDto"]["seq"];

		// T_THEMEテーブルより、ThemeDtoを取得する。
		$themeDtoDao = new ThemeDtoDao();
		$themeDto = $themeDtoDao->find($seq, TRUE);
		
		if ($themeDto == NULL) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_THEME_INFO_NOT_FOUND, array($seq));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		// 権限チェック
		if (!AuthorityUtil::isThemeEditable($themeDto)) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_AUTHORITY);
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// 表示項目に値を設定する。
		$themeDtoArray = array();
		$themeDto->copyToArray($themeDtoArray);
		$actionInfo->form["themeDto"] = $themeDtoArray; 
		
		$actionInfo->viewName = 'ThemeEditView';
	}

	public function deleteTheme(ActionInfo &$actionInfo) {
		$form = &$actionInfo->form;
		$request = &$actionInfo->request;
		
		// 入力値チェック
		$validate = TRUE;
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'seq', 'Seq', $request["themeDto"]["seq"], TRUE, TRUE);
		if (!$validate) {
			// エラー
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		$seq = $request["themeDto"]["seq"];

		// T_THEMEテーブルより、ThemeDtoを取得する。
		$themeDtoDao = new ThemeDtoDao();
		$themeDto = $themeDtoDao->find($seq, TRUE);
		
		if ($themeDto == NULL) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_THEME_INFO_NOT_FOUND, array($seq));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		// 権限チェック
		if (!AuthorityUtil::isThemeEditable($themeDto)) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_AUTHORITY);
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// コレクションが存在しないことを確認する。
		$collectionDtoDao = new CollectionDtoDao();
		$collectionDtoList = $collectionDtoDao->findByThemeSeq($seq, FALSE);
		if (count($collectionDtoList) > 0) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NOT_DELETE_THEME_1, array());
			$actionInfo->form["seq"] = $seq;
			$actionInfo->forwardActionName = "ThemeBrowse";
			return;
		}
		
		// 表示項目に値を設定する。
		$themeDtoArray = array();
		$themeDto->copyToArray($themeDtoArray);
		$actionInfo->form["themeDto"] = $themeDtoArray; 
		
		$actionInfo->viewName = 'ThemeDeleteView';
	}
	
	public function reloadTheme(ActionInfo &$actionInfo) {
		$actionInfo->form = $actionInfo->request;
		
		$actionInfo->viewName = 'ThemeEditView';
	}

	/**
	 * @param ActionInfo $actionInfo
	 * @return void|void|void
	 */
	public function addUser(ActionInfo &$actionInfo) {
		$form = &$actionInfo->form;
		$request = &$actionInfo->request;
		
		// 入力値チェック
		$validate = TRUE;
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'userId', 'UserId', $request["userId"], TRUE, TRUE);
		if (!$validate) {
			// エラー
			$actionInfo->form = $request;
			$actionInfo->viewName = 'ThemeEditView';
			return;
		}
		$userId = $request["userId"];
		
		// 入力されたユーザIDがT_USERに存在していることを確認する。
		$userDtoDao = new UserDtoDao();
		$userDto = $userDtoDao->findByUserId($userId);
		if ($userDto == NULL) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_USER_INFO_NOT_FOUND,array($userId));
			$actionInfo->form = $request;
			$actionInfo->viewName = 'ThemeEditView';
			return;
		}

		// テーマユーザ情報リストに存在しないことを確認する。
		$errorFlg = FALSE;
		if (isset($request["themeDto"]["themeUserDtoList"])) {
			foreach ($request["themeDto"]["themeUserDtoList"] as $themeUserDtoArray) {
				if ($themeUserDtoArray["userId"] == $userDto->userId) {
					$errorFlg = TRUE;
				}
			}
			if ($errorFlg) {
				// エラー
				$actionInfo->errorMessageList[] = getMessage(MSG_USER_ALREADY_EXISTS,array($userId));
				$actionInfo->form = $request;
				$actionInfo->viewName = 'ThemeEditView';
				return;
			}
		} else {
			$request["themeDto"]["themeUserDtoList"] = array();
		}
		
		// テーマユーザ情報を作成し、テーマユーザ情報リストに追加する。
		$themeUserDtoArray = array();
		$themeUserDtoArray["userSeq"] = $userDto->seq;
		$themeUserDtoArray["userId"] = $userDto->userId;
		$themeUserDtoArray["nickName"] = $userDto->nickName;
		$themeUserDtoArray["enable"] = FLAG_TRUE;
		$request["themeDto"]["themeUserDtoList"][] = $themeUserDtoArray;
		
		$actionInfo->form = $request;
		$actionInfo->viewName = 'ThemeEditView';
	}
	public function deleteUser($idx, ActionInfo &$actionInfo) {
		$request = &$actionInfo->request;
		
		if (isset($request["themeDto"]["themeUserDtoList"][$idx])) {
			array_splice($request["themeDto"]["themeUserDtoList"], $idx, 1);
		}
		
		$actionInfo->form = $request;
		$actionInfo->viewName = 'ThemeEditView';
	}
}
?>