<?php
class ThemeRegisterAction extends BaseAction {
	public function action(ActionInfo &$actionInfo) {
		$command = (count($actionInfo->commands) > 0) ? $actionInfo->commands[0] : NULL;
		if (isBlank($command)) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_COMMAND);
			$actionInfo->viewName = "AppricationErrorView";
			return;
		} else if ($command == "confirm") {
			$this->confirm($actionInfo);
		} else if ($command == "register") {
			$this->register($actionInfo);
		} else if ($command == "delete") {
			$this->delete($actionInfo);
		} else {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_UNKNOWN_COMMAND, array($command));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
	}
	
	public function confirm(ActionInfo &$actionInfo) {
		// 入力値チェック
		$validate = $this->validate($actionInfo);
		if (!$validate) {
			// エラー
			$actionInfo->form = $actionInfo->request;
			$actionInfo->viewName = "ThemeEditView";
			return;
		}
		
		$actionInfo->form = $actionInfo->request;
		$actionInfo->viewName = "ThemeConfirmView";
	}
	public function register(ActionInfo &$actionInfo) {
		// 入力値チェック
		$validate = $this->validate($actionInfo);
		if (!$validate) {
			// エラー
			$actionInfo->form = $actionInfo->request;
			$actionInfo->viewName = "ThemeEditView";
			return;
		}
		$themeDtoArray = $actionInfo->request["themeDto"];

		// formからdtoに変換
		$themeDto = new ThemeDto();
		$themeDto->copyFromArray($themeDtoArray);

		// 権限チェック
		if ((isBlank($themeDto->seq) && !AuthorityUtil::isThemeCreatable())
			|| (!isBlank($themeDto->seq) && !AuthorityUtil::isThemeEditable($themeDto)))
		{
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_AUTHORITY);
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// 古い値の保持
		$this->retainThemeDtoValues($themeDto);
		
		// 入力されたテーマ情報をテーブルに登録/更新する。
		$themeDtoDao = new ThemeDtoDao();
		$themeDtoDao->register($themeDto, true);
		
		$actionInfo->noticeMessageList[] = getMessage(MSG_REGISTERING_THEME_SUCCEED);
		$actionInfo->forwardActionName = 'ThemeList';
	}

	public function delete(ActionInfo &$actionInfo) {
		$form = &$actionInfo->form;
		$request = &$actionInfo->request;
		
		// 入力値チェック
		$validate = TRUE;
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'seq', 'Seq', $request["themeDto"]["seq"], TRUE, TRUE);
		if (!$validate) {
			// エラー
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		$seq = $request["themeDto"]["seq"];

		// T_THEMEテーブルより、ThemeDtoを取得する。
		$themeDtoDao = new ThemeDtoDao();
		$themeDto = $themeDtoDao->find($seq, TRUE);
		
		if ($themeDto == NULL) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_THEME_INFO_NOT_FOUND, array($seq));
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		// 権限チェック
		if (!AuthorityUtil::isThemeEditable($themeDto)) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NO_AUTHORITY);
			$actionInfo->viewName = "AppricationErrorView";
			return;
		}
		
		// コレクションが存在しないことを確認する。
		$collectionDtoDao = new CollectionDtoDao();
		$collectionDtoList = $collectionDtoDao->findByThemeSeq($seq, FALSE);
		if (count($collectionDtoList) > 0) {
			// エラー
			$actionInfo->errorMessageList[] = getMessage(MSG_NOT_DELETE_THEME_1, array());
			$actionInfo->form["seq"] = $seq;
			$actionInfo->forwardActionName = "ThemeBrowse";
			return;
		}
		
		// テーマの削除を行う
		$themeDtoDao->delete($seq);
		
		// テーマ一覧画面にフォワードする
		$actionInfo->noticeMessageList[] = getMessage(MSG_DELETING_THEME_SUCCEED);
		$actionInfo->forwardActionName = "ThemeList";
	}
	
	private function validate(ActionInfo &$actionInfo) {
		$themeDtoArray = (isset($actionInfo->request["themeDto"])) ? $actionInfo->request["themeDto"] : array(); 

		$validate = TRUE;
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'seq', 'Seq', $themeDtoArray["seq"], FALSE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'title1', 'Title1', $themeDtoArray["title1"], TRUE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'title2', 'Title2', $themeDtoArray["title2"], FALSE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'title3', 'Title3', $themeDtoArray["title3"], FALSE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'title4', 'Title4', $themeDtoArray["title4"], FALSE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'description1', 'Description1', $themeDtoArray["description1"], TRUE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'description2', 'Description2', $themeDtoArray["description2"], FALSE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'description3', 'Description3', $themeDtoArray["description3"], FALSE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'description4', 'Description4', $themeDtoArray["description4"], FALSE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'collectionNum', 'CollectionNum', $themeDtoArray["collectionNum"], TRUE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'sortNo', 'SortNo', $themeDtoArray["sortNo"], TRUE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'collectionDetailNum', 'CollectionDetailNum', $themeDtoArray["collectionDetailNum"], TRUE, TRUE);
		$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'themeStatus', 'ThemeStatus', $themeDtoArray["themeStatus"], TRUE, TRUE);
		
		$themeUserDtoListArray = $themeDtoArray["themeUserDtoList"];
		if (isset($themeUserDtoListArray) && is_array($themeUserDtoListArray)) {
			foreach($themeUserDtoListArray as $key => $themeUserDtoArray) {
				$lines = array($key+1);
				$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'userSeq', 'Seq', $themeUserDtoArray["userSeq"], TRUE, TRUE, $lines);
				$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'enable', 'Flag', $themeUserDtoArray["enable"], TRUE, TRUE, $lines);
				$validate = $validate & ValidateUtil::validate($actionInfo->errorMessageList,'sortNo', 'SortNo', $themeUserDtoArray["sortNo"], TRUE, TRUE, $lines);
			}
		}
		return $validate;
	}

	private function retainThemeDtoValues(ThemeDto &$dto) {
		if (!isBlank($dto->seq)) {
			$themeDtoDao = new ThemeDtoDao();
			$oldDto = $themeDtoDao->find($dto->seq, FALSE);
			if ($oldDto != null) {
				$dto->title1 = (isset($dto->title1)) ? $dto->title1 : $oldDto->title1;
				$dto->title2 = (isset($dto->title2)) ? $dto->title2 : $oldDto->title2;
				$dto->title3 = (isset($dto->title3)) ? $dto->title3 : $oldDto->title3;
				$dto->title4 = (isset($dto->title4)) ? $dto->title4 : $oldDto->title4;
				$dto->description1 = (isset($dto->description1)) ? $dto->description1 : $oldDto->description1;
				$dto->description2 = (isset($dto->description2)) ? $dto->description2 : $oldDto->description2;
				$dto->description3 = (isset($dto->description3)) ? $dto->description3 : $oldDto->description3;
				$dto->description4 = (isset($dto->description4)) ? $dto->description4 : $oldDto->description4;
			}
		}
	}
}
?>