<?php
class CollectionDtoDao extends AbstractCollectionDtoDao {
	public function find($seq, $withCollectionDetailDto) {
		$collectionDetalDtoDao = new CollectionDetailDtoDao();
		
		$result = NULL;
		$joinedTableName = "T_COLLECTION A LEFT JOIN T_USER B ON A.USER_SEQ=B.SEQ";
		$joinedItemColumns = array_merge(append_prefix("A.",$this->itemColumns), array("B.USER_ID","B.NICK_NAME"));
		$queryValues = array($seq);
		$rowsets = SingletonUtil::$databaseUtil->executeSelect($joinedTableName, $joinedItemColumns, "WHERE A.SEQ = ?", $queryValues);
		if (count($rowsets) > 0) {
			$result = $this->createDtoFromArray($rowsets[0]);
			if ($withCollectionDetailDto) {
				$result->collectionDetailDtoList = $collectionDetalDtoDao->findByCollectionSeq($result->seq);
			}
	    }
		return $result;
	}
	public function findByThemeSeq($themeSeq, $withCollectionDetailDto, $collectionStatus = NULL, $from = -1, $to = -1) {
		$collectionDetalDtoDao = new CollectionDetailDtoDao();
		
		$result = array();
		$joinedTableName = "T_COLLECTION A LEFT JOIN T_USER B ON A.USER_SEQ=B.SEQ LEFT JOIN T_THEME_USER C ON A.USER_SEQ=C.USER_SEQ AND A.THEME_SEQ=C.THEME_SEQ";
		$joinedItemColumns = array_merge(append_prefix("A.",$this->itemColumns), array("B.USER_ID","B.NICK_NAME"));
		$queryValues = array($themeSeq);
		$queryStr = "WHERE A.THEME_SEQ = ?";
		
		if ($collectionStatus !== NULL) {
			$queryStr .= " AND ".DaoUtil::generateValueList($queryValues,"COLLECTION_STATUS",$collectionStatus);
		}
		
		$queryStr .= " ORDER BY C.SORT_NO, A.SORT_NO";
		$rowsets = SingletonUtil::$databaseUtil->executeSelect($joinedTableName, $joinedItemColumns, $queryStr, $queryValues, $from, $to);
		foreach ($rowsets as $rowset) {
			$dto = $this->createDtoFromArray($rowset);
			if ($withCollectionDetailDto) {
				$dto->collectionDetailDtoList = $collectionDetalDtoDao->findByCollectionSeq($dto->seq); 
			}
			$result[] = $dto;
	    }
		return $result;
	}
	public function findPrevByThemeSeqAndSortNo($themeSeq, $sortNo, $withCollectionDetailDto) {
		$collectionDetalDtoDao = new CollectionDetailDtoDao();
		
		$result = NULL;
		$joinedTableName = "T_COLLECTION A LEFT JOIN T_USER B ON A.USER_SEQ=B.SEQ LEFT JOIN T_THEME_USER C ON A.USER_SEQ=C.USER_SEQ AND A.THEME_SEQ=C.THEME_SEQ";
		$joinedItemColumns = array_merge(append_prefix("A.",$this->itemColumns), array("B.USER_ID","B.NICK_NAME"));
		$queryValues = array($themeSeq,$sortNo);
		$queryStr = "WHERE A.THEME_SEQ = ? AND A.SORT_NO < ? ORDER BY C.SORT_NO DESC, A.SORT_NO DESC LIMIT 1";
		$rowsets = SingletonUtil::$databaseUtil->executeSelect($joinedTableName, $joinedItemColumns, $queryStr, $queryValues);
		if (count($rowsets) > 0) {
			$result = $this->createDtoFromArray($rowsets[0]);
			if ($withCollectionDetailDto) {
				$result->collectionDetailDtoList = $collectionDetalDtoDao->findByCollectionSeq($result->seq);
			}
	    }
		return $result;
	}
	public function findNextByThemeSeqAndSortNo($themeSeq, $sortNo, $withCollectionDetailDto) {
		$collectionDetalDtoDao = new CollectionDetailDtoDao();
		
		$result = NULL;
		$joinedTableName = "T_COLLECTION A LEFT JOIN T_USER B ON A.USER_SEQ=B.SEQ LEFT JOIN T_THEME_USER C ON A.USER_SEQ=C.USER_SEQ AND A.THEME_SEQ=C.THEME_SEQ";
		$joinedItemColumns = array_merge(append_prefix("A.",$this->itemColumns), array("B.USER_ID","B.NICK_NAME"));
		$queryValues = array($themeSeq,$sortNo);
		$queryStr = "WHERE A.THEME_SEQ = ? AND A.SORT_NO > ? ORDER BY C.SORT_NO ASC, A.SORT_NO ASC LIMIT 1";
		$rowsets = SingletonUtil::$databaseUtil->executeSelect($joinedTableName, $joinedItemColumns, $queryStr, $queryValues);
		if (count($rowsets) > 0) {
			$result = $this->createDtoFromArray($rowsets[0]);
			if ($withCollectionDetailDto) {
				$result->collectionDetailDtoList = $collectionDetalDtoDao->findByCollectionSeq($result->seq);
			}
	    }
		return $result;
	}
	public function findByThemeSeqAndUserSeq($themeSeq, $userSeq, $withCollectionDetailDto) {
		$collectionDetalDtoDao = new CollectionDetailDtoDao();
		
		$result = NULL;
		$joinedTableName = "T_COLLECTION A LEFT JOIN T_USER B ON A.USER_SEQ=B.SEQ";
		$joinedItemColumns = array_merge(append_prefix("A.",$this->itemColumns), array("B.USER_ID","B.NICK_NAME"));
		$queryValues = array($themeSeq,$userSeq);
		$queryStr = "WHERE A.THEME_SEQ = ? AND A.USER_SEQ = ?";
		$rowsets = SingletonUtil::$databaseUtil->executeSelect($joinedTableName, $joinedItemColumns, $queryStr, $queryValues);
		if (count($rowsets) > 0) {
			$result = $this->createDtoFromArray($rowsets[0]);
			if ($withCollectionDetailDto) {
				$result->collectionDetailDtoList = $collectionDetalDtoDao->findByCollectionSeq($result->seq);
			}
	    }
		return $result;
	}
	public function findCountByThemeSeq($themeSeq) {
		$itemColumns = array("COUNT(*) NUM");
		$queryValues = array($themeSeq);
		$rowsets = SingletonUtil::$databaseUtil->executeSelect($this->tableName, $itemColumns, "WHERE THEME_SEQ = ?", $queryValues);
		if (count($rowsets) > 0) {
			return $rowsets[0]["NUM"];
		} else {
			return 0;
		}
	}
	public function findMaxSubSeq($themeSeq) {
		$itemColumns = array("MAX(SUB_SEQ) SUB_SEQ");
		$queryValues = array($themeSeq);
		$rowsets = SingletonUtil::$databaseUtil->executeSelect($this->tableName, $itemColumns, "WHERE THEME_SEQ = ?", $queryValues);
		if (count($rowsets) > 0) {
			return $rowsets[0]["SUB_SEQ"];
		} else {
			return 0;
		}
	}
	public function findMaxSortNo($themeSeq) {
		$itemColumns = array("MAX(SORT_NO) SORT_NO");
		$queryValues = array($themeSeq);
		$rowsets = SingletonUtil::$databaseUtil->executeSelect($this->tableName, $itemColumns, "WHERE THEME_SEQ = ?", $queryValues);
		if (count($rowsets) > 0) {
			return $rowsets[0]["SORT_NO"];
		} else {
			return -1;
		}
	}
	public function delete($seq){
		$collectionDetailDtoDao = new CollectionDetailDtoDao();
		$queryValues = array($seq);
		$result = SingletonUtil::$databaseUtil->executeDelete($this->tableName, "WHERE SEQ = ?", $queryValues);
		$collectionDetailDtoDao->deleteByCollectionSeq($seq);
		return $result;
	}
	public function register(CollectionDto $collectionDto, $withCollectionDetailDto){
		$collectionDetailDtoDao = new CollectionDetailDtoDao();
		if ($collectionDto->seq == null) {
			$collectionDto->subSeq = $this->findMaxSubSeq($collectionDto->themeSeq) + 1;
			$insertValues = $this->createArrayFromDto($collectionDto);
			$seq = SingletonUtil::$databaseUtil->executeInsert($this->tableName, $this->getItemColumnsForInput(), $insertValues);
			$collectionDto->seq = $seq;
		} else {
			$updateValues = $this->createArrayFromDto($collectionDto);
			$queryValues = array($collectionDto->seq);
			SingletonUtil::$databaseUtil->executeUpdate($this->tableName, $this->getItemColumnsForInput(), "WHERE SEQ = ?", $queryValues, $updateValues);
			if ($withCollectionDetailDto) {
				$collectionDetailDtoDao->deleteByCollectionSeq($collectionDto->seq);
			}
		}
		if ($withCollectionDetailDto) {
			$subSeq = 0;
			foreach($collectionDto->collectionDetailDtoList as $collectionDetailDto) {
				$collectionDetailDto->seq = NULL;
				$collectionDetailDto->subSeq = $subSeq;
				$collectionDetailDto->collectionSeq = $collectionDto->seq;
				$collectionDetailDtoDao->register($collectionDetailDto);
				$subSeq++;
			}
		}
	}
}
?>
