<?php
class UserDtoDao extends AbstractUserDtoDao {
	public function find($seq, $withUserAttributeDto = FALSE) {
		$userAttributeDtoDao = new UserAttributeDtoDao();
		$result = NULL;
		$queryValues = array($seq);
		$rowsets = SingletonUtil::$databaseUtil->executeSelect($this->tableName, $this->itemColumns, "WHERE SEQ = ?", $queryValues);
		if (count($rowsets) > 0) {
			$result = $this->createDtoFromArray($rowsets[0]);
			if ($withUserAttributeDto) {
				$result->userAttributeDtoList = $userAttributeDtoDao->findByUserSeq($result->seq);
			}
		}
		return $result;
	}
	public function findByUserId($userId) {
		$result = NULL;
		$queryValues = array($userId);
		$rowsets = SingletonUtil::$databaseUtil->executeSelect($this->tableName, $this->itemColumns, "WHERE USER_ID = ?", $queryValues);
		if (count($rowsets) > 0) {
			$result = $this->createDtoFromArray($rowsets[0]);
	    }
		return $result;
	}
	public function findByUserIdAndPasswordHash($userId, $passwordHash) {
		$result = NULL;
		$queryValues = array($userId, $passwordHash);
		$rowsets = SingletonUtil::$databaseUtil->executeSelect($this->tableName, $this->itemColumns, "WHERE USER_ID = ? AND PASSWORD_HASH = ?", $queryValues);
		if (count($rowsets) > 0) {
			$result = $this->createDtoFromArray($rowsets[0]);
	    }
		return $result;
	}
	public function findAll($withUserAttributeDto, $from = -1, $to = -1) {
		$userAttributeDtoDao = new UserAttributeDtoDao();
		$result = array();
		$queryValues = array();
		$queryStr = "";

		$queryStr .= " ORDER BY SEQ";
		$rowsets = SingletonUtil::$databaseUtil->executeSelect($this->tableName, $this->itemColumns, $queryStr, $queryValues, $from, $to);
		foreach ($rowsets as $rowset) {
			$dto = $this->createDtoFromArray($rowset);
			if ($withUserAttributeDto) {
				$dto->userAttributeDtoList = $userAttributeDtoDao->findByUserSeq($dto->seq);
			}
			$result[] = $dto;
	    }
		return $result;
	}
	public function findCount() {
		$itemColumns = array("COUNT(*) NUM");
		$queryValues = array();
		$queryStr = "";
				
		$rowsets = SingletonUtil::$databaseUtil->executeSelect($this->tableName, $itemColumns, $queryStr, $queryValues);
		if (count($rowsets) > 0) {
			return $rowsets[0]["NUM"];
		} else {
			return 0;
		}
	}
	public function delete($seq){
		$queryValues = array($seq);
		$result = SingletonUtil::$databaseUtil->executeDelete($this->tableName, "WHERE SEQ = ?", $queryValues);
		return $result;
	}
	public function register(UserDto $userDto, $withUserAttributeDto = FALSE) {
		$userAttributeDtoDao = new UserAttributeDtoDao();
		if ($userDto->seq == null) {
			$insertValues = $this->createArrayFromDto($userDto);
			$seq = SingletonUtil::$databaseUtil->executeInsert($this->tableName, $this->getItemColumnsForInput(), $insertValues);
			$userDto->seq = $seq;
		} else {
			$updateValues = $this->createArrayFromDto($userDto);
			$queryValues = array($userDto->seq);
			SingletonUtil::$databaseUtil->executeUpdate($this->tableName, $this->getItemColumnsForInput(), "WHERE SEQ = ?", $queryValues, $updateValues);
			if ($withUserAttributeDto) {
				$userAttributeDtoDao->deleteByUserSeq($userDto->seq);
			}
		}
		if ($withUserAttributeDto) {
			foreach($userDto->userAttributeDtoList as $userAttributeDto) {
				$userAttributeDto->seq = NULL;
				$userAttributeDto->userSeq = $userDto->seq;
				$userAttributeDtoDao->register($userAttributeDto);
			}
		}
	}
}
?>
