<?php
class DatabaseUtil {
	public $databaseHandler = NULL;
	public function createDatabaseHandler() {
		global $databaseDsn;
		if ($this->databaseHandler == NULL) {
			$this->databaseHandler = new PDO($databaseDsn, NULL, NULL);
			$this->databaseHandler->setAttribute(PDO::ATTR_ERRMODE,PDO::ERRMODE_EXCEPTION);
		} else {
			throw new Exception(MSG_DB_ALREADY_CONNECTED);
		}
	}
	public function beginTransaction() {
		return $this->databaseHandler->beginTransaction();
	}
	public function commit() {
		return $this->databaseHandler->commit();
	}
	public function rollBack() {
		$result = TRUE;
		if ($this->databaseHandler != NULL) {
			$result = $this->databaseHandler->rollBack();
		}
		return $result;
	}
	public function disposeDatabaseHandler() {
		$this->databaseHandler = NULL;
	}
	public function prepare($statement) {
		$result = $this->databaseHandler->prepare($statement);
		if ($result instanceof PDOException) {
			throw $result;
		}
		if (!$result) {
			if (DEBUG_MODE) {
				die("Error on Prepare statement:".$statement);
			} else {
				die("Error on Prepare statement");
			}
		}
		return $result;
	}
	public function createSelectStatement($tableName, array $itemColumns, $query) {
		$sql = "SELECT ".implode(",",$itemColumns)." FROM ".$tableName;
		if (!isBlank($query)) {
			$sql .= " ".$query;
		}
		$stmt = $this->prepare($sql);
		return $stmt;
	}
	public function createInsertStatement($tableName, array $itemColumns) {
		$firstFlag = TRUE;
		$itemArray="";
		$valueArray="";
		foreach($itemColumns as $item) {
			if ($firstFlag) {
				$firstFlag = FALSE;
				$itemArray = $item;
				$valueArray = "?";
			} else {
				$itemArray .= ",".$item;
				$valueArray .= ",?";
			}
		} 
		$sql = "INSERT INTO ".$tableName."(".$itemArray.") VALUES (".$valueArray.")";
		$stmt = $this->prepare($sql);
		return $stmt;
	}
	public function createUpdateStatement($tableName, array $itemColumns, $query) {
		$firstFlag = TRUE;
		$itemArray="";
		foreach($itemColumns as $item) {
			if ($firstFlag) {
				$firstFlag = FALSE;
				$itemArray = $item."=?";
			} else {
				$itemArray .= ",".$item."=?";
			}
		} 
		$sql = "UPDATE ".$tableName." SET ".$itemArray;
		if (!isBlank($query)) {
			$sql .= " ".$query;
		} else {
			die("Updating all rows is not arrowed.");
		}
		$stmt = $this->prepare($sql);
		return $stmt;
	}
	public function createDeleteStatement($tableName, $query) {
		$sql = "DELETE FROM ".$tableName." ".$query;
		$stmt = $this->prepare($sql);
		return $stmt;
	}
	public function executeSelect($tableName, array &$itemColumns, $query, array &$queryValues, $from = -1, $to = -1) {
		$themeUserDtoDao = new ThemeUserDtoDao();
		$result = NULL;
		$stmt = $this->createSelectStatement($tableName, $itemColumns, $query);
		$stmt->execute($queryValues);
		$result = array();
		$row = FALSE;
		$idx = 1;
		// TODO : FROM-TOの処理がどんくさいので直すこと
		while ($idx < $from) {
			$stmt->fetch();
			$idx++;
		}
		while (($row = $stmt->fetch(PDO::FETCH_ASSOC)) !== FALSE) {
			$result[] = $row;
			$idx++;
			if ($to > 0 && $idx > $to) {
				break;
			}
		}
		$stmt->closeCursor();
		return $result;
	}
	public function executeInsert($tableName, array &$itemColumns, array &$insertValues) {
		$curDate = date("Y/m/d H:i:s");
		$curUserId = UserUtil::getUserId();
		$insertValues["CREATE_USER"] = $curUserId;
		$insertValues["CREATE_TIMESTAMP"] = $curDate;
		$insertValues["UPDATE_USER"] = $curUserId;
		$insertValues["UPDATE_TIMESTAMP"] = $curDate;
		
		$values = array();
		foreach($itemColumns as $itemColumn) {
			if (isset($insertValues[$itemColumn])) {
				$values[] = $insertValues[$itemColumn];
			} else {
				$values[] = NULL;
			}
		}
		$stmt = $this->createInsertStatement($tableName, $itemColumns);
		$result = $stmt->execute($values);
		$result = $this->databaseHandler->lastInsertId();
		$stmt->closeCursor();
		return $result;
	}
	public function executeUpdate($tableName, array &$itemColumns, $query, array &$queryValues, array &$updateValues) {
		$curDate = date("Y/m/d H:i:s");
		$curUserId = UserUtil::getUserId();
		$updateValues["UPDATE_USER"] = $curUserId;
		$updateValues["UPDATE_TIMESTAMP"] = $curDate;
		
		$values = array();
		foreach($itemColumns as $itemColumn) {
			if (isset($updateValues[$itemColumn])) {
				$values[] = $updateValues[$itemColumn];
			} else {
				$values[] = NULL;
			}
		}
		$values = array_merge($values, $queryValues);
		$stmt = $this->createUpdateStatement($tableName, $itemColumns, $query);
		$result = $stmt->execute($values);
		$result = $stmt->rowCount();
		$stmt->closeCursor();
		if ($result !== 1) {
			throw new PDOException("More than one rows updated:".$tableName.":".$result);
		}
		return $result;
	}
	public function executeDelete($tableName, $query, array &$queryValues) {
		$values = array();
		$stmt = $this->createDeleteStatement($tableName, $query);
		$result = $stmt->execute($queryValues);
		$result = $stmt->rowCount();
		$stmt->closeCursor();
		return $result;
	}
	public function exec($sql) {
		return $this->databaseHandler->exec($sql);
	}
};
?>
