<?php
class ImageUtil {
	static function createImageDto(UserDto $userDto, &$imageFile, array &$messages) {
		global $imageFileDir, $thumbnailWidth;
		
		$originalImage = NULL;
		$originalTmpFileName = NULL;
		$originalRawFileName = $imageFile['name']; 
		if ($imageFile['type'] == "image/png" || $imageFile['type'] == "image/x-png") {
			$originalTmpFileName = $imageFile['tmp_name'];
			$originalImage = imagecreatefrompng($originalTmpFileName);
		} elseif ($imageFile['type'] == "image/jpeg" || $imageFile['type'] == "image/pjpeg") {
			$originalTmpFileName = $imageFile['tmp_name'];
			$originalImage = imagecreatefromjpeg($originalTmpFileName);
		}
		
		if ($originalImage == NULL) {
			$messages[] = getMessage(MSG_NOT_SUPPORTED_FILE_TYPE,$originalImage['type']);
			return NULL;
		}
		
		list($srcWidth, $srcHeight) = getimagesize($originalTmpFileName);
		$dstWidth = $thumbnailWidth;
       $dstHeight = $dstWidth * $srcHeight / $srcWidth;
		$thumbnailImage = imagecreatetruecolor($dstWidth, $dstHeight);
		imagecopyresampled($thumbnailImage, $originalImage, 0, 0, 0, 0, $dstWidth, $dstHeight, $srcWidth, $srcHeight);
		
		$imageFileName = ImageUtil::generateFileName($userDto->seq, ".jpg");
		imagejpeg($originalImage, $imageFileDir.$imageFileName);
		$thumbnailFileName = ImageUtil::generateFileName($userDto->seq, ".jpg");
		imagejpeg($thumbnailImage, $imageFileDir.$thumbnailFileName);
		imagedestroy($thumbnailImage);
		imagedestroy($originalImage);
		
		$fileDtoDao = new FileDtoDao();
		$imageFileDto = new FileDto();
		$imageFileDto->originalFileName = $originalRawFileName;
		$imageFileDto->realFileName = $imageFileName;
		$imageFileDto->userSeq = $userDto->seq;
		$thumbnailFileDto = new FileDto();
		$thumbnailFileDto->originalFileName = $thumbnailFileName;
		$thumbnailFileDto->realFileName = $thumbnailFileName;
		$thumbnailFileDto->userSeq = $userDto->seq;
		$fileDtoDao->register($imageFileDto);
		$fileDtoDao->register($thumbnailFileDto);
		
		$imageDtoDao = new ImageDtoDao();
		$imageDto = new ImageDto();
		$imageDto->nickName = $userDto->nickName;
		$imageDto->imageFileSeq = $imageFileDto->seq;
		$imageDto->imageRealFileName = $imageFileDto->realFileName;
		$imageDto->imageOriginalFileName = $imageFileDto->originalFileName;
		$imageDto->thumbnailFileSeq = $thumbnailFileDto->seq;
		$imageDto->thumbnailRealFileName = $thumbnailFileDto->realFileName;
		$imageDto->thumbnailOriginalFileName = $thumbnailFileDto->originalFileName;
		
		$imageDtoDao->register($imageDto);
		
		return $imageDto;
	}
	static function generateFileName($userSeq,$extension) {
		global $imageFileDir;
		$i = 0;
		do {
			$fileName = sprintf('%04d', $userSeq).date("YmdHis").sprintf('%02d', $i).$extension;
		} while (file_exists($imageFileDir.$fileName));
		return $fileName;
	}
}
?>
